import dotenv from 'dotenv';
dotenv.config();
export const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
export let sealKey = "";
export let baseURL = "";
export let apiPath = "";
if (isProduction) {
    sealKey = process.env.SEAL_PROD_KEY;
    baseURL = process.env.BASE_URL_PROD;
    apiPath = process.env.API_PATH_PROD;
}
else {
    sealKey = process.env.SEAL_PROD_DEV;
    baseURL = process.env.BASE_URL_DEV;
    apiPath = process.env.API_PATH_DEV;
}
export var httpTypes;
(function (httpTypes) {
    httpTypes["get"] = "GET";
    httpTypes["post"] = "POST";
})(httpTypes || (httpTypes = {}));
export var serviceTypes;
(function (serviceTypes) {
    serviceTypes["allSubs"] = "allSubs";
    serviceTypes["subDetails"] = "subDetails";
    serviceTypes["magicLink"] = "magicLink";
})(serviceTypes || (serviceTypes = {}));
export var subStates;
(function (subStates) {
    subStates["active"] = "ACTIVE";
    subStates["paused"] = "PAUSED";
    subStates["cancelled"] = "CANCELLED";
    subStates["expired"] = "EXPIRED";
})(subStates || (subStates = {}));
export var intervals;
(function (intervals) {
    intervals["monthly"] = "1 month";
    intervals["annual"] = "12 month";
})(intervals || (intervals = {}));
export var currencies;
(function (currencies) {
    currencies["cad"] = "CAD";
    currencies["usd"] = "USD";
})(currencies || (currencies = {}));
export var billingStates;
(function (billingStates) {
    billingStates["successful"] = "completed";
})(billingStates || (billingStates = {}));
export const services = {
    [serviceTypes.allSubs]: {
        method: httpTypes.get,
        endPoint: 'subscriptions',
        argStr: null
    },
    [serviceTypes.subDetails]: {
        method: httpTypes.get,
        endPoint: 'subscription?id={ID}',
        argStr: '{ID}'
    },
    [serviceTypes.magicLink]: {
        method: httpTypes.get,
        endPoint: 'customer-magic-link?email={EMAIL}',
        argStr: '{EMAIL}'
    }
};
