var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { serviceTypes, services, baseURL, sealKey, apiPath } from "./constants/generalConstants.js";
import exceptionalError from "exceptionalhandler";
import fetch from 'node-fetch';
export function performSealRequest(reqType, arg = null) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(reqType in serviceTypes)) {
            throw new exceptionalError(`Unknown API req type ${reqType}`);
        }
        let reqParams = setReqParams(reqType, arg);
        let parsedResponse = yield doTheApiThing(reqParams, reqType);
        if (reqType === serviceTypes.allSubs) {
            yield checkPagination(parsedResponse, reqParams, reqType);
        }
        return parsedResponse;
    });
}
function checkPagination(parsedResponse, ogReqParams, reqType) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!parsedResponse.payload.page) {
            throw new exceptionalError(`Somehow ended up with a subs response w/ no pages?`);
        }
        while (parsedResponse.payload.page < parsedResponse.payload.total_pages) {
            let newReqDetails = {
                url: `${ogReqParams.url}?page=${parsedResponse.payload.page + 1}`,
                fetchOpts: ogReqParams.fetchOpts
            };
            let newResp = yield doTheApiThing(newReqDetails, reqType);
            if (newResp.payload && newResp.payload.subscriptions && newResp.payload.page) {
                for (const subDeets of newResp.payload.subscriptions) {
                    parsedResponse.payload.subscriptions.push(subDeets);
                }
                parsedResponse.payload.page = newResp.payload.page;
            }
            else {
                parsedResponse.payload.page = 999999;
                break;
            }
        }
    });
}
function doTheApiThing(reqParams, reqType) {
    return __awaiter(this, void 0, void 0, function* () {
        let req;
        try {
            req = yield fetch(reqParams.url, reqParams.fetchOpts);
        }
        catch (e) {
            throw e;
            // maybe handle this better later
        }
        let resp = yield handleResponse(req, reqType);
        return resp;
    });
}
function setReqParams(reqType, arg) {
    const apiReqDeets = services[reqType];
    let reqUrl = `${baseURL}${apiPath}${apiReqDeets.endPoint}`;
    if (apiReqDeets.argStr) {
        if (!arg) {
            throw new exceptionalError(`Arg '${apiReqDeets.argStr}' is required for ${reqType}`);
        }
        reqUrl = reqUrl.replace(apiReqDeets.argStr, arg);
    }
    else {
        if (arg) {
            throw new exceptionalError(`${reqType} has no args but you provided "${arg}"`);
        }
    }
    return {
        url: reqUrl,
        fetchOpts: {
            method: apiReqDeets.method,
            headers: {
                'X-Seal-Token': sealKey
            }
        }
    };
}
function handleResponse(apiResp, reqType) {
    return __awaiter(this, void 0, void 0, function* () {
        switch (apiResp.status) {
            case 200:
                let body = yield apiResp.json();
                if (!body.success) {
                    let errMsg = '';
                    if (!body.error) {
                        errMsg = 'No Error Provided';
                    }
                    else {
                        errMsg = body.error;
                    }
                    throw new exceptionalError(`Seal API Req ${reqType} returned ${apiResp.status} but success was false with error "${errMsg}"`);
                }
                return body;
                break;
            default:
                let errMsg = '';
                if (apiResp.body) {
                    errMsg = getBodyErrMsg(yield apiResp.text());
                }
                throw new exceptionalError(`Seal API Req ${reqType} returned ${apiResp.status} w/ body "${errMsg}"`);
                break;
        }
    });
}
function getBodyErrMsg(bodyText) {
    const errRegex = /error":"(.+?)"/i;
    let retStr = '';
    if (bodyText.match(errRegex)) {
        retStr = `Error: ${bodyText.match(errRegex)[1]}`;
    }
    return retStr;
}
