var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import convertSubscription from './sealConversions.js';
import { serviceTypes } from './constants/generalConstants.js';
import { performSealRequest } from './sealApi.js';
import { info as logInfo } from 'logger';
import exceptionalError from 'exceptionalhandler';
import util from 'util';
export let sealErrs = [];
export function getAllSubs() {
    return __awaiter(this, void 0, void 0, function* () {
        sealErrs = [];
        let retVals = [];
        let subList = yield getSubList();
        for (const subEntry of subList) {
            const subId = subEntry.id;
            try {
                let deets = yield getSubById(subId);
                if (deets) {
                    retVals.push(deets);
                }
            }
            catch (e) {
                logInfo(util.inspect(e, { depth: null }));
                if (e.message.match(/404/)) {
                    sealErrs.push(`No sub details found for subId ${subId} (${subEntry.email})`);
                }
                else {
                    throw e;
                }
            }
        }
        return retVals;
    });
}
function getSubList() {
    return __awaiter(this, void 0, void 0, function* () {
        let subList = yield performSealRequest(serviceTypes.allSubs);
        let subs = [];
        if (subList.success && subList.payload && subList.payload.subscriptions) {
            for (const subEntry of subList.payload.subscriptions) {
                subs.push(subEntry);
            }
        }
        return subs;
    });
}
export function getSubById(subId) {
    return __awaiter(this, void 0, void 0, function* () {
        let subDeets = yield performSealRequest(serviceTypes.subDetails, subId);
        if (subDeets) {
            let formattedVal = convertSubscription(subDeets);
            if (!formattedVal) {
                throw new exceptionalError(`Bad/Unexpected API resp for sub details subId ${subId}`);
            }
            return formattedVal;
        }
        return null;
    });
}
export function getMagicLink(userEmail) {
    return __awaiter(this, void 0, void 0, function* () {
        sealErrs = [];
        if (!userEmail || !(typeof userEmail === 'string') || !userEmail.match(/^\w.+?@.+?\..+?$/i)) {
            throw new exceptionalError(`Invalid email address provided`);
        }
        let magicLinkBody = yield performSealRequest(serviceTypes.magicLink, userEmail);
        if (!magicLinkBody.payload || !magicLinkBody.payload.magic_link || magicLinkBody.payload.magic_link == '') {
            throw new exceptionalError(`API returned a good response but the link was missing`);
        }
        return magicLinkBody.payload.magic_link;
    });
}
