import dotenv from 'dotenv';
dotenv.config();
export const isProduction: boolean = (process.env.NODE_ENV === 'PRODUCTION');

export let sealKey: string = "";
export let baseURL: string = "";
export let apiPath: string = "";
if(isProduction){
    sealKey = process.env.SEAL_PROD_KEY as string;
    baseURL = process.env.BASE_URL_PROD as string;
    apiPath = process.env.API_PATH_PROD as string;
} else {
    sealKey = process.env.SEAL_PROD_DEV as string;
    baseURL = process.env.BASE_URL_DEV as string;
    apiPath = process.env.API_PATH_DEV as string;
}


export interface reqParams{
    url: string,
    fetchOpts: any
}

export enum httpTypes{
    "get" = "GET",
    "post" = "POST"
}

export enum serviceTypes{
    allSubs = "allSubs",
    subDetails = "subDetails",
    magicLink = "magicLink"
}

type reqMapping = {
    [serviceName in serviceTypes]: {
        method: httpTypes,
        endPoint: string,
        argStr: null|string
    }
}

export enum subStates{
    active = "ACTIVE",
    paused = "PAUSED",
    cancelled = "CANCELLED",
    expired = "EXPIRED"
}

export enum intervals{
    monthly = "1 month",
    annual = "12 month"
}

export enum currencies{
    cad = "CAD",
    usd = "USD"
}

export enum billingStates{
    successful = "completed"
}

export const services:reqMapping = {
    [serviceTypes.allSubs]:{
        method: httpTypes.get,
        endPoint: 'subscriptions',
        argStr: null
    },
    [serviceTypes.subDetails]:{
        method: httpTypes.get,
        endPoint: 'subscription?id={ID}',
        argStr: '{ID}'
    },
    [serviceTypes.magicLink]:{
        method: httpTypes.get,
        endPoint: 'customer-magic-link?email={EMAIL}',
        argStr: '{EMAIL}'
    }
}