import {subDetailsApiResp} from './constants/apiResps.js';
import {niceSubObj, niceItem, niceBillingRecord} from './constants/niceObjs.js'
import { billingStates } from './constants/generalConstants.js';


export default function convertSubscription(apiResp: subDetailsApiResp): niceSubObj|null{
    if(!apiResp){
        return null;
    }
    
    let respObj: niceSubObj = {
        shopSubId: apiResp.payload.id,
        sealSubId: apiResp.payload.internal_id,
        created: new Date(apiResp.payload.order_placed),
        customerId: apiResp.payload.customer_id,
        email: apiResp.payload.email,
        interval: apiResp.payload.billing_interval,
        subCurrency: apiResp.payload.currency,
        chargePerInterval: apiResp.payload.total_value,
        subStatus: apiResp.payload.status,
        subAdminPageUrl: apiResp.payload.edit_url,
        originalOrderId: Number(apiResp.payload.order_id),
        items: [],
        billing: []
    };

    for (const subItem of apiResp.payload.items){
        let newItem: niceItem = {
            variantId: subItem.variant_id,
            title: subItem.title,
            qty: subItem.quantity,
            price: subItem.final_amount
        }
        respObj.items.push(newItem);
    }

    for (const billingItem of apiResp.payload.billing_attempts){
        if(billingItem.status !== billingStates.successful){
            continue;
        }

        let newBillingItem: niceBillingRecord = {
            date: new Date(billingItem.date),
            sealId: billingItem.id,
            shopOrderId: billingItem.order_id
        }

        respObj.billing.push(newBillingItem);
    }

    return respObj;
}
