import convertSubscription from './sealConversions.js'
import { serviceTypes } from './constants/generalConstants.js'
import { getAllSubsApiResp, subDetailsApiResp, magicLinkApiResp, apiSubOverview } from './constants/apiResps.js'
import { niceSubObj } from './constants/niceObjs.js'
import { performSealRequest } from './sealApi.js'
import { info as logInfo } from 'logger'
import exceptionalError from 'exceptionalhandler'
import util from 'util'

export let sealErrs: string[] = []

export async function getAllSubs() {
    sealErrs = [];

    let retVals: niceSubObj[] = [];
    let subList = await getSubList();
    for (const subEntry of subList) {
        const subId = subEntry.id
        try {
            let deets = await getSubById(subId)
            if (deets) {
                retVals.push(deets)
            }
        } catch (e) {
            logInfo(util.inspect(e, { depth: null }))
            if ((<Error>e).message.match(/404/)) {
                sealErrs.push(`No sub details found for subId ${subId} (${subEntry.email})`)
            } else {
                throw e;
            }
        }
    }
    return retVals;
}


async function getSubList() {
    let subList: getAllSubsApiResp = await performSealRequest(serviceTypes.allSubs)
    let subs: apiSubOverview[] = [];
    if (subList.success && subList.payload && subList.payload.subscriptions) {
        for (const subEntry of subList.payload.subscriptions) {
            subs.push(subEntry);
        }
    }
    return subs;
}


export async function getSubById(subId: string): Promise<niceSubObj | null> {
    let subDeets: subDetailsApiResp = await performSealRequest(serviceTypes.subDetails, subId);
    if (subDeets) {
        let formattedVal = convertSubscription(subDeets);
        if (!formattedVal) {
            throw new exceptionalError(`Bad/Unexpected API resp for sub details subId ${subId}`)
        }
        return formattedVal as niceSubObj;
    }
    return null
}


export async function getMagicLink(userEmail: string) {
    sealErrs = [];
    if (!userEmail || !(typeof userEmail === 'string') || !userEmail.match(/^\w.+?@.+?\..+?$/i)) {
        throw new exceptionalError(`Invalid email address provided`);
    }
    let magicLinkBody = await performSealRequest(serviceTypes.magicLink, userEmail) as magicLinkApiResp;
    if (!magicLinkBody.payload || !magicLinkBody.payload.magic_link || magicLinkBody.payload.magic_link == '') {
        throw new exceptionalError(`API returned a good response but the link was missing`);
    }
    return magicLinkBody.payload.magic_link
}