import * as apiMocker from "makeapimockery";

import chai from 'chai';
chai.config.truncateThreshold = 0;
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);

import * as niceObj from '../constants/niceObjs.js'
import * as apiResps from '../constants/apiResps.js'
import * as seal from '../sealthedeal.js'


describe(`Testing Pagination`, async () => {
    before(async() => {
        apiMocker.addService("seal", "seal.json")
        apiMocker.printToConsole(false);
        apiMocker.start();
    })

    context('Paginate that', async() => {
        it('Works', async() => {
            apiMocker.addToQueue("seal", "get", {caseName: "paginationPg1", requirements: {url: /subscriptions$/}})
            apiMocker.addToQueue("seal", "get", {caseName: "paginationPg2", requirements: {url: /subscriptions\?page=2$/}})
            apiMocker.addToQueue("seal", "get", {caseName: "paginationPg3", requirements: {url: /subscriptions\?page=3$/}})
            apiMocker.addToQueue("seal", "get", {caseName: "get1649440", requirements: {url: /subscription\?id=1649440$/}})
            apiMocker.addToQueue("seal", "get", {caseName: "get1649385", requirements: {url: /subscription\?id=1649385$/}})
            apiMocker.addToQueue("seal", "get", {caseName: "get1649171", requirements: {url: /subscription\?id=1649171$/}})

            let expectedVal = [
                {
                  shopSubId: 1649440,
                  sealSubId: 1003,
                  originalOrderId: 5505340965111,
                  created:  new Date("2024-01-23T18:33:33.000Z"),
                  customerId: '7117224771831',
                  email: 'chris.nevin@repairify.com',
                  interval: '1 month',
                  subCurrency: 'USD',
                  chargePerInterval: 198,
                  subStatus: 'ACTIVE',
                  subAdminPageUrl: 'https://9ee16c-3.myshopify.com/a/subscriptions/manage/zcps/authenticate/?sealkey=f34cd3602530be5a892599c93bcadc00ed72bcba05a738424f4431fd481bb378',
                  items: [
                    {
                      variantId: '44201046835447',
                      title: 'BaaS Subscription',
                      qty: 2,
                      price: 198
                    }
                  ],
                  billing: []
                },
                {
                  shopSubId: 1649385,
                  sealSubId: 1002,
                  originalOrderId: 5505315209463,
                  created: new Date("2024-01-23T18:11:13.000Z"),
                  customerId: '7117224771831',
                  email: 'chris.nevin@repairify.com',
                  interval: '12 month',
                  subCurrency: 'USD',
                  chargePerInterval: 999,
                  subStatus: 'ACTIVE',
                  subAdminPageUrl: 'https://9ee16c-3.myshopify.com/a/subscriptions/manage/zco9/authenticate/?sealkey=7dfa200274da48dd9f89ca2440669b44720f2baceb177e18ef0bbcd4effb5f6d',
                  items: [
                    {
                      variantId: '44201046835447',
                      title: 'BaaS Subscription',
                      qty: 1,
                      price: 999
                    }
                  ],
                  billing: [
                    {
                      date: new Date("2025-01-23T18:00:00.000Z"),
                      sealId: 13656476,
                      shopOrderId: '5505342439671'
                    }
                  ]
                },
                {
                  shopSubId: 1649171,
                  sealSubId: 1001,
                  originalOrderId: 5505205797111,
                  created: new Date("2024-01-23T16:25:31.000Z"),
                  customerId: '7138815475959',
                  email: 'chrs.nevin@repairify.com',
                  interval: '12 month',
                  subCurrency: 'USD',
                  chargePerInterval: 1998,
                  subStatus: 'ACTIVE',
                  subAdminPageUrl: 'https://9ee16c-3.myshopify.com/a/subscriptions/manage/zcib/authenticate/?sealkey=c28119a87c78bb6809accb2c3c579915c14f8906f84690b8be590a3c811ef397',
                  items: [
                    {
                      variantId: '44201046835447',
                      title: 'BaaS Subscription',
                      qty: 2,
                      price: 1998
                    }
                  ],
                  billing: []
                }
            ]


            let fullResponse = await seal.getAllSubs();
            expect(seal.sealErrs).to.be.empty;
            expect(apiMocker.getQueuedItems()).to.equal(0)
            
            expect(fullResponse).to.deep.equal(expectedVal)
        })

    })
});