import chai from 'chai';
chai.config.truncateThreshold = 0;
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);

import convertSubscription from '../sealConversions.js';
import * as testCases from './cases/conversion.cases.js';
import * as niceObj from '../constants/niceObjs.js'
import * as apiResps from '../constants/apiResps.js'
import * as generalConsts from '../constants/generalConstants.js'

describe(`Testing conversions`, () => {
    context(`Converting detailed API resps to nice objects`, () => {
        it(`Works with initial order`, () => {
            let expectedResult: niceObj.niceSubObj = {
                shopSubId: 1649171,
                sealSubId: 1001,
                interval: generalConsts.intervals.annual,
                created: new Date("2024-01-23T12:55:31-03:30"),
                email: "chrs.nevin@repairify.com",
                subCurrency: generalConsts.currencies.usd,
                chargePerInterval: 1998,
                subStatus: generalConsts.subStates.active,
                subAdminPageUrl: "www.vocm.com",
                customerId: "7138815475959",
                originalOrderId: 5505205797111,
                items: [{
                    variantId: "44201046835447",
                    title: "BaaS Subscription",
                    qty: 2,
                    price: 1998
                }],
                billing: []
            }
            expect(convertSubscription(testCases.initialOrder)).to.deep.equal(expectedResult);
        })

        it(`Works with order and multiple recharges`, () => {
            let expectedResult: niceObj.niceSubObj = {
                shopSubId: 1649385,
                sealSubId: 1002,
                interval: generalConsts.intervals.monthly,
                created: new Date("2024-01-23T14:41:13-03:30"),
                email: "some.guy@email.com",
                subCurrency: generalConsts.currencies.usd,
                chargePerInterval: 123456,
                subStatus: generalConsts.subStates.active,
                subAdminPageUrl: "www.zombo.com",
                customerId: "ABC123",
                originalOrderId: 5505315209463,
                items: [{
                    variantId: "123456789",
                    title: "Some Other Thing",
                    qty: 3,
                    price: 1998
                }],
                billing: [{
                    date:  new Date("2025-01-23T18:00:00+00:00"),
                    sealId: 13656476,
                    shopOrderId: "5505342439671"
                }]
            }
            expect(convertSubscription(testCases.multipleBillings)).to.deep.equal(expectedResult);
        })
    })
});